X-Git-Url: https://git.saurik.com/wxWidgets.git/blobdiff_plain/fd3f686c274a264e89ea97505350a82c1134f307..c59f6793fb6c116e6b9abdaca4de0c4a08a0e5b0:/include/wx/listimpl.cpp?ds=sidebyside

diff --git a/include/wx/listimpl.cpp b/include/wx/listimpl.cpp
index ccb1e6397c..11d0196a4e 100644
--- a/include/wx/listimpl.cpp
+++ b/include/wx/listimpl.cpp
@@ -6,19 +6,33 @@
 // Created:     16/11/98
 // RCS-ID:      $Id$
 // Copyright:   (c) 1998 Vadim Zeitlin
-// Licence:   	wxWindows license
+// Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
-#define _DEFINE_LIST(T, name)           \
-    void wx##name##Node::DeleteData()   \
-    {                                   \
-        delete (T *)GetData();          \
-    }
+#if wxUSE_STL
 
-// redefine the macro so that now it will generate the class implementation
-// old value would provoke a compile-time error if this file is not included
-#undef  WX_DEFINE_LIST
-#define WX_DEFINE_LIST(name) _DEFINE_LIST(_WX_LIST_ITEM_TYPE_##name, name)
+    #undef  WX_DEFINE_LIST
+    #define WX_DEFINE_LIST(name)                                        \
+        void name::DeleteFunction( const _WX_LIST_ITEM_TYPE_##name X )  \
+        {                                                               \
+            delete X;                                                   \
+        }
+
+#else // if !wxUSE_STL
+
+    #define _DEFINE_LIST(T, name)         \
+        void wx##name##Node::DeleteData() \
+        {                                 \
+            delete (T *)GetData();        \
+        }
+
+    // redefine the macro so that now it will generate the class implementation
+    // old value would provoke a compile-time error if this file is not included
+    #undef  WX_DEFINE_LIST
+    #define WX_DEFINE_LIST(name) _DEFINE_LIST(_WX_LIST_ITEM_TYPE_##name, name)
+
+    // don't pollute preprocessor's name space
+    //#undef  _DEFINE_LIST
+
+#endif
 
-// don't pollute preprocessor's name space
-//#undef  _DEFINE_LIST